'use client';
import { CSSProperties, useState, useEffect } from 'react';

// Улучшенные стили с градиентами и эффектами
const wrapper: CSSProperties = {
  position: 'fixed',
  inset: 0,
  background: 'rgba(0,0,0,.7)',
  backdropFilter: 'blur(12px)',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  zIndex: 1000,
  transition: 'all 0.3s ease',
  padding: '20px',
};

const modal: CSSProperties = {
  position: 'relative',
  background: 'linear-gradient(145deg, #0a0a0a, #1a1a1a)',
  border: '1px solid #ff7f27',
  borderRadius: 24,
  padding: 40,
  minWidth: 700, // Увеличено для более широкого профиля
  maxWidth: '90vw',
  width: '100%', // Добавлено для лучшего контроля ширины
  color: '#ff7f27',
  boxShadow: '0 8px 40px rgba(255,127,39,.25), 0 0 0 1px rgba(255,127,39,0.1)',
  transformOrigin: 'center',
  transition: 'transform 0.3s cubic-bezier(0.175, 0.885, 0.32, 1.275)',
  animation: 'profileCardAppear 0.4s forwards',
};

const profileHeader: CSSProperties = {
  position: 'relative',
  marginBottom: 30,
  display: 'flex',
  alignItems: 'center',
  gap: 30,
};

const avatarContainer: CSSProperties = {
  position: 'relative',
  width: 140,
  height: 140,
  borderRadius: '50%',
  background: 'linear-gradient(145deg, #ff7f27, #f9560b)',
  boxShadow: '0 5px 15px rgba(255, 127, 39, 0.3)',
  animation: 'pulseGlow 3s infinite',
  overflow: 'hidden',
};

const avatarImage: CSSProperties = {
  width: '100%',
  height: '100%',
  objectFit: 'cover',
  borderRadius: '50%',
};

const profileInfo: CSSProperties = {
  flex: 1,
};

const username: CSSProperties = {
  fontSize: 28, 
  marginBottom: 12, 
  fontWeight: 'bold',
  textShadow: '0 2px 10px rgba(255,127,39,0.3)',
  background: 'linear-gradient(to right, #ff7f27, #ff5500)',
  WebkitBackgroundClip: 'text',
  WebkitTextFillColor: 'transparent',
};

const fullname: CSSProperties = {
  fontSize: 18, 
  marginBottom: 12,
  color: 'rgba(255,255,255,0.9)',
};

const closeBtn: CSSProperties = {
  position: 'absolute',
  top: 16,
  right: 16,
  background: 'rgba(0,0,0,0.4)',
  border: '1px solid rgba(255,127,39,0.3)',
  fontSize: 20,
  color: '#ff7f27',
  cursor: 'pointer',
  width: 36,
  height: 36,
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
  borderRadius: '50%',
  transition: 'all 0.2s',
};

const divider: CSSProperties = {
  width: '100%',
  height: 2,
  background: 'linear-gradient(to right, transparent, rgba(255,127,39,0.5), transparent)',
  margin: '20px 0',
  borderRadius: 2,
};

const tabsContainer: CSSProperties = {
  display: 'flex',
  borderBottom: '1px solid rgba(255,127,39,0.3)',
  marginBottom: 20,
};

const tab: CSSProperties = {
  padding: '12px 20px',
  color: 'rgba(255,255,255,0.6)',
  cursor: 'pointer',
  transition: 'all 0.3s',
  borderBottom: '2px solid transparent',
  fontSize: 16,
  fontWeight: 'bold',
};

const tabActive: CSSProperties = {
  color: '#ff7f27',
  borderBottom: '2px solid #ff7f27',
  background: 'rgba(255,127,39,0.1)',
};

const tabContent: CSSProperties = {
  minHeight: 200,
  padding: '20px 0',
};

const settingsButton: CSSProperties = {
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
  gap: 8,
  width: '100%',
  padding: '12px 0',
  borderRadius: 12,
  background: 'linear-gradient(145deg, #ff7f27, #ff5500)',
  color: '#000',
  fontWeight: 'bold',
  fontSize: 16,
  cursor: 'pointer',
  border: 0,
  boxShadow: '0 4px 12px rgba(255,127,39,0.4)',
  transition: 'all 0.2s',
  marginTop: 10,
};

const logoutButton: CSSProperties = {
  display: 'block',
  margin: '12px auto 0',
  padding: '8px 12px',
  background: 'transparent',
  border: '1px solid rgba(255,127,39,0.5)',
  color: '#ff7f27',
  borderRadius: 8,
  fontSize: 14,
  cursor: 'pointer',
  transition: 'all 0.2s',
};

const emptyState: CSSProperties = {
  display: 'flex',
  flexDirection: 'column',
  alignItems: 'center',
  justifyContent: 'center',
  padding: '40px 0',
  color: 'rgba(255,255,255,0.5)',
  textAlign: 'center',
};

const ticketCard: CSSProperties = {
  background: 'linear-gradient(145deg, rgba(40,40,40,0.7), rgba(20,20,20,0.9))',
  borderRadius: 16,
  padding: 24,
  marginBottom: 16,
  border: '1px solid rgba(255,127,39,0.3)',
  boxShadow: '0 5px 15px rgba(0,0,0,0.3)',
  position: 'relative',
  overflow: 'hidden',
  animation: 'fadeIn 0.5s forwards',
};

const ticketHeader: CSSProperties = {
  display: 'flex',
  justifyContent: 'space-between',
  alignItems: 'flex-start',
  marginBottom: 12,
};

const ticketTitle: CSSProperties = {
  fontSize: 22,
  fontWeight: 'bold',
  color: '#fff',
  marginBottom: 8,
};

const ticketNumber: CSSProperties = {
  fontSize: 20,
  fontWeight: 'bold',
  color: '#ff7f27',
  padding: '6px 12px',
  background: 'rgba(255,127,39,0.15)',
  borderRadius: 10,
  letterSpacing: 1,
};

const ticketDetails: CSSProperties = {
  display: 'flex',
  justifyContent: 'space-between',
  padding: '12px 0',
  borderTop: '1px dashed rgba(255,255,255,0.2)',
  borderBottom: '1px dashed rgba(255,255,255,0.2)',
  margin: '15px 0',
};

const ticketDetail: CSSProperties = {
  display: 'flex',
  flexDirection: 'column',
};

const ticketLabel: CSSProperties = {
  fontSize: 12,
  color: 'rgba(255,255,255,0.5)',
  marginBottom: 5,
};

const ticketValue: CSSProperties = {
  fontSize: 14,
  color: 'rgba(255,255,255,0.9)',
};


const ticketPaymentId: CSSProperties = {
  fontSize: 12,
  color: 'rgba(255,255,255,0.5)',
  marginTop: 10,
  wordBreak: 'break-all',
};



// Добавим интерфейс для более полных данных пользователя
interface UserData {
  login: string;
  avatar: string;
  first_name: string;
  last_name: string;
  middle_name: string | null;
  email: string;
  full_name?: string; // Для обратной совместимости
}

export default function ProfileModal({
  user,
  onClose,
  onSettings,
}: {
  user: { avatar: string; login: string; full_name: string };
  onClose: () => void;
  onSettings: () => void;
}) {
  const [activeTab, setActiveTab] = useState('tickets');
  const [userData, setUserData] = useState<UserData | null>(null);
  // Removed unused loading state
  
  // Получение ID пользователя из cookie
  const userId = document.cookie
    .split('; ')
    .find(row => row.startsWith('id='))
    ?.split('=')[1];
    
  // Получение токена из cookie (removed unused token variable)
  
  // Загрузка полных данных пользователя при открытии профиля
  useEffect(() => {
    if (userId) {
      fetchUserData(userId);
    } else {
      setLoading(false);
    }
  }, [userId]);
  
  // Функция получения данных пользователя
  const fetchUserData = async (id: string) => {
    try {
      const response = await fetch(`http://localhost:8000/user/${id}`, {
        method: 'GET',
        headers: {
          'Content-Type': 'application/json',
        },
        credentials: 'include',
      });
      
      if (response.ok) {
        const data = await response.json();
        console.log("Получены данные пользователя:", data);
        setUserData(data);
      } else {
        console.error("Ошибка при получении данных пользователя");
      }
    } catch (error) {
      console.error("Ошибка запроса:", error);
    } finally {
      setLoading(false);
    }
  };
  
  // Функция форматирования полного имени
  const formatName = () => {
    if (userData) {
      const parts = [];
      if (userData.last_name) parts.push(userData.last_name);
      if (userData.first_name) parts.push(userData.first_name);
      if (userData.middle_name) parts.push(userData.middle_name);
      return parts.join(' ');
    }
    
    // Fallback к старому формату, если нет новых данных
    return user.full_name || '';
  };

  return (
    <div
      style={wrapper}
      onClick={(e) => e.target === e.currentTarget && onClose()}
    >

      <div style={modal}>
        <button 
          onClick={onClose} 
          style={closeBtn} 
          aria-label="Закрыть"
          onMouseOver={(e) => {
            e.currentTarget.style.background = 'rgba(255,127,39,0.2)';
            e.currentTarget.style.transform = 'scale(1.1)';
          }}
          onMouseOut={(e) => {
            e.currentTarget.style.background = 'rgba(0,0,0,0.4)';
            e.currentTarget.style.transform = 'scale(1)';
          }}
        >
          ✕
        </button>

        <div style={profileHeader}>
          <div style={avatarContainer}>
            <img
              src={userData?.avatar || user.avatar}
              alt={`${userData?.login || user.login} avatar`}
              style={avatarImage}
              onContextMenu={(e) => e.preventDefault()}
              onDragStart={(e) => e.preventDefault()}
            />
          </div>

          <div style={profileInfo}>
            <h2 style={username}>
              {userData?.login || user.login}
            </h2>
            
            {formatName() && (
              <p style={fullname}>
                {formatName()}
              </p>
            )}
            
            {/* Добавляем отображение email */}
            {userData?.email && (
              <p style={{ 
                fontSize: 14, 
                color: 'rgba(255,255,255,0.7)',
                display: 'flex',
                alignItems: 'center',
                gap: 6
              }}>
                <svg width="14" height="14" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
                  <path d="M4 4H20C21.1 4 22 4.9 22 6V18C22 19.1 21.1 20 20 20H4C2.9 20 2 19.1 2 18V6C2 4.9 2.9 4 4 4Z" stroke="rgba(255,255,255,0.7)" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                  <path d="M22 6L12 13L2 6" stroke="rgba(255,255,255,0.7)" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
                </svg>
                {userData.email}
              </p>
            )}
          </div>
        </div>

        <div style={divider}></div>
        
        {/* Вкладки */}
        <div style={tabsContainer}>
          <div 
            style={{
              ...tab,
              ...(activeTab === 'tickets' ? tabActive : {})
            }}
            onClick={() => setActiveTab('tickets')}
          >
            Мои билеты
          </div>
          <div 
            style={{
              ...tab,
              ...(activeTab === 'history' ? tabActive : {})
            }}
            onClick={() => setActiveTab('history')}
          >
            История заказов
          </div>
        </div>
        
        {/* Содержимое вкладок */}
        <div style={tabContent} className={`tab-content-active`}>
          {activeTab === 'tickets' && (
            <div>
              <div style={ticketCard}>
                <div style={ticketHeader}>
                  <div>
                    <div style={ticketTitle}>Зеленый слоник 2</div>
                  </div>
                  <div style={ticketNumber}>F22SB21</div>
                </div>
                
                <div style={ticketDetails}>
                  <div style={ticketDetail}>
                    <span style={ticketLabel}>ДАТА</span>
                    <span style={ticketValue}>21.05.2025</span>
                  </div>
                  
                  <div style={ticketDetail}>
                    <span style={ticketLabel}>ВРЕМЯ</span>
                    <span style={ticketValue}>19:30</span>
                  </div>
                  
                  <div style={ticketDetail}>
                    <span style={ticketLabel}>ЗАЛ</span>
                    <span style={ticketValue}>Главный</span>
                  </div>
                  
                  <div style={ticketDetail}>
                    <span style={ticketLabel}>МЕСТО</span>
                    <span style={ticketValue}>VIP 12</span>
                  </div>
                </div>
                
                <div style={ticketPaymentId}>
                  <span style={{color: 'rgba(255,127,39,0.8)', marginRight: 5}}>Код платежа:</span>
                  2fbd2cd4-000f-5001-9000-1fb8d8bcd8a9
                </div>
                

              </div>
            </div>
          )}
          
          {activeTab === 'history' && (
            <div style={emptyState}>
              <svg width="60" height="60" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" style={{ marginBottom: 16, opacity: 0.5 }}>
                <path d="M12 8V12L15 15M21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3C16.9706 3 21 7.02944 21 12Z" stroke="#ff7f27" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
              </svg>
              <h3 style={{ color: 'rgba(255,255,255,0.8)', marginBottom: 8 }}>История заказов пуста</h3>
              <p style={{ maxWidth: '70%', margin: '0 auto' }}>Здесь появится история ваших прошлых заказов</p>
            </div>
          )}
        </div>

        <button
          onClick={onSettings}
          style={settingsButton}
          onMouseOver={(e) => {
            e.currentTarget.style.transform = 'translateY(-2px)';
            e.currentTarget.style.boxShadow = '0 6px 15px rgba(255,127,39,0.5)';
          }}
          onMouseOut={(e) => {
            e.currentTarget.style.transform = 'translateY(0)';
            e.currentTarget.style.boxShadow = '0 4px 12px rgba(255,127,39,0.4)';
          }}
        >
          <svg width="16" height="16" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
            <path d="M12 15C13.6569 15 15 13.6569 15 12C15 10.3431 13.6569 9 12 9C10.3431 9 9 10.3431 9 12C9 13.6569 10.3431 15 12 15Z" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
            <path d="M19.4 15C19.2669 15.3016 19.2272 15.6362 19.286 15.9606C19.3448 16.285 19.4995 16.5843 19.73 16.82L19.79 16.88C19.976 17.0657 20.1235 17.2863 20.2241 17.5291C20.3248 17.7719 20.3766 18.0322 20.3766 18.295C20.3766 18.5578 20.3248 18.8181 20.2241 19.0609C20.1235 19.3037 19.976 19.5243 19.79 19.71C19.6043 19.896 19.3837 20.0435 19.1409 20.1441C18.8981 20.2448 18.6378 20.2966 18.375 20.2966C18.1122 20.2966 17.8519 20.2448 17.6091 20.1441C17.3663 20.0435 17.1457 19.896 16.96 19.71L16.9 19.65C16.6643 19.4195 16.365 19.2648 16.0406 19.206C15.7162 19.1472 15.3816 19.1869 15.08 19.32C14.7842 19.4468 14.532 19.6572 14.3543 19.9255C14.1766 20.1938 14.0813 20.5082 14.08 20.83V21C14.08 21.5304 13.8693 22.0391 13.4942 22.4142C13.1191 22.7893 12.6104 23 12.08 23C11.5496 23 11.0409 22.7893 10.6658 22.4142C10.2907 22.0391 10.08 21.5304 10.08 21V20.91C10.0723 20.579 9.96512 20.258 9.77251 19.9887C9.5799 19.7194 9.31074 19.5143 9 19.4C8.69838 19.2669 8.36381 19.2272 8.03941 19.286C7.71502 19.3448 7.41568 19.4995 7.18 19.73L7.12 19.79C6.93425 19.976 6.71368 20.1235 6.47088 20.2241C6.22808 20.3248 5.96783 20.3766 5.705 20.3766C5.44217 20.3766 5.18192 20.3248 4.93912 20.2241C4.69632 20.1235 4.47575 19.976 4.29 19.79C4.10405 19.6043 3.95653 19.3837 3.85588 19.1409C3.75523 18.8981 3.70343 18.6378 3.70343 18.375C3.70343 18.1122 3.75523 17.8519 3.85588 17.6091C3.95653 17.3663 4.10405 17.1457 4.29 16.96L4.35 16.9C4.58054 16.6643 4.73519 16.365 4.794 16.0406C4.85282 15.7162 4.81312 15.3816 4.68 15.08C4.55324 14.7842 4.34276 14.532 4.07447 14.3543C3.80618 14.1766 3.49179 14.0813 3.17 14.08H3C2.46957 14.08 1.96086 13.8693 1.58579 13.4942C1.21071 13.1191 1 12.6104 1 12.08C1 11.5496 1.21071 11.0409 1.58579 10.6658C1.96086 10.2907 2.46957 10.08 3 10.08H3.09C3.42099 10.0723 3.742 9.96512 4.0113 9.77251C4.28059 9.5799 4.48572 9.31074 4.6 9C4.73312 8.69838 4.77282 8.36381 4.714 8.03941C4.65519 7.71502 4.50054 7.41568 4.27 7.18L4.21 7.12C4.02405 6.93425 3.87653 6.71368 3.77588 6.47088C3.67523 6.22808 3.62343 5.96783 3.62343 5.705C3.62343 5.44217 3.67523 5.18192 3.77588 4.93912C3.87653 4.69632 4.02405 4.47575 4.21 4.29C4.39575 4.10405 4.61632 3.95653 4.85912 3.85588C5.10192 3.75523 5.36217 3.70343 5.625 3.70343C5.88783 3.70343 6.14808 3.75523 6.39088 3.85588C6.63368 3.95653 6.85425 4.10405 7.04 4.29L7.1 4.35C7.33568 4.58054 7.63502 4.73519 7.95941 4.794C8.28381 4.85282 8.61838 4.81312 8.92 4.68H9C9.29577 4.55324 9.54802 4.34276 9.72569 4.07447C9.90337 3.80618 9.99872 3.49179 10 3.17V3C10 2.46957 10.2107 1.96086 10.5858 1.58579C10.9609 1.21071 11.4696 1 12 1C12.5304 1 13.0391 1.21071 13.4142 1.58579C13.7893 1.96086 14 2.46957 14 3V3.09C14.0013 3.41179 14.0966 3.72618 14.2743 3.99447C14.452 4.26276 14.7042 4.47324 15 4.6C15.3016 4.73312 15.6362 4.77282 15.9606 4.714C16.285 4.65519 16.5843 4.50054 16.82 4.27L16.88 4.21C17.0657 4.02405 17.2863 3.87653 17.5291 3.77588C17.7719 3.67523 18.0322 3.62343 18.295 3.62343C18.5578 3.62343 18.8181 3.67523 19.0609 3.77588C19.3037 3.87653 19.5243 4.02405 19.71 4.21C19.896 4.39575 20.0435 4.61632 20.1441 4.85912C20.2448 5.10192 20.2966 5.36217 20.2966 5.625C20.2966 5.88783 20.2448 6.14808 20.1441 6.39088C20.0435 6.63368 19.896 6.85425 19.71 7.04L19.65 7.1C19.4195 7.33568 19.2648 7.63502 19.206 7.95941C19.1472 8.28381 19.1869 8.61838 19.32 8.92V9C19.4468 9.29577 19.6572 9.54802 19.9255 9.72569C20.1938 9.90337 20.5082 9.99872 20.83 10H21C21.5304 10 22.0391 10.2107 22.4142 10.5858C22.7893 10.9609 23 11.4696 23 12C23 12.5304 22.7893 13.0391 22.4142 13.4142C22.0391 13.7893 21.5304 14 21 14H20.91C20.5882 14.0013 20.2738 14.0966 20.0055 14.2743C19.7372 14.452 19.5268 14.7042 19.4 15Z" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round"/>
          </svg>
          Настройки профиля
        </button>

        <button
          onClick={onClose}
          style={logoutButton}
          onMouseOver={(e) => {
            e.currentTarget.style.background = 'rgba(255,127,39,0.1)';
          }}
          onMouseOut={(e) => {
            e.currentTarget.style.background = 'transparent';
          }}
        >
          Выйти
        </button>
      </div>
    </div>
  );
}
function setLoading(isLoading: boolean) {
    console.log(`Loading state set to: ${isLoading}`);
}

